@@ -14,7 +14,6 @@ deleteUsers <- function(rcon,
 
 deleteUsers.redcapApiConnection <- function(rcon, 
                                             users, 
-                                            refresh = TRUE,
                                             ..., 
                                             error_handling = getOption("redcap_error_handling"), 
                                             config = list(), 
@@ -33,11 +32,6 @@ deleteUsers.redcapApiConnection <- function(rcon,
                               any.missing = FALSE,
                               add = coll)
   
-  checkmate::assert_logical(x = refresh, 
-                            len = 1, 
-                            null.ok = FALSE, 
-                            add = coll)
-  
   error_handling <- checkmate::matchArg(x = error_handling, 
                                         choices = c("null", "error"),
                                         .var.name = "error_handling",
@@ -77,14 +71,12 @@ deleteUsers.redcapApiConnection <- function(rcon,
                           body = c(body, api_param), 
                           config = config)
   
+  rcon$flush_users()
+  
   if (response$status_code != 200){
     redcapError(response, 
                  error_handling = error_handling)
   }
   
-  if (refresh){
-    rcon$refresh_users()
-  }
-  
   invisible(as.character(response))
 }
