@@ -58,7 +58,5 @@ exportDags.redcapApiConnection <- function(rcon,
   
   if (response$status_code != 200) return(redcapError(response, error_handling))
   
-  utils::read.csv(text = as.character(response), 
-                  na.strings = "",
-                  stringsAsFactors = FALSE)
+  as.data.frame(response)
 }
