@@ -83,11 +83,6 @@ exportEvents.redcapApiConnection <- function(rcon,
   
   if (response$status_code != 200) return(redcapError(response, error_handling))
 
-  if (trimws(as.character(response)) == ""){
-    REDCAP_EVENT_STRUCTURE
-  } else {
-    utils::read.csv(text = as.character(response),
-                    stringsAsFactors = FALSE,
-                    na.strings = "")
-  }
+  response <- as.data.frame(response)
+  if(nrow(response) == 0) REDCAP_EVENT_STRUCTURE else response
 }
