@@ -5,8 +5,8 @@
 exportFiles <- function(rcon, 
                         record, 
                         field, 
-                        event      = NULL, 
-                        dir, 
+                        event       = NULL, 
+                        dir         = getwd(), 
                         file_prefix = TRUE, 
                         ...){
   UseMethod("exportFiles")
@@ -20,8 +20,8 @@ exportFiles.redcapApiConnection <- function(rcon,
                                             record, 
                                             field, 
                                             event           = NULL, 
-                                            dir, 
-                                            file_prefix      = TRUE, 
+                                            dir             = getwd(), 
+                                            file_prefix     = TRUE, 
                                             repeat_instance = NULL,
                                             ...,
                                             error_handling  = getOption("redcap_error_handling"),
