@@ -137,9 +137,11 @@ importRecords.redcapApiConnection <- function(rcon,
                                               batch.size        = -1,
                                               error_handling = getOption("redcap_error_handling"), 
                                               config = list(), 
-                                              api_param = list()){
-  message("importRecords will change how it validates data in version 3.0.0.\n",
-          "We recommend preparing your data for import using castForImport.")
+                                              api_param = list())
+{
+  if(is.null(attr(data, "castForImport")))
+    message("importRecords will change how it validates data in version 3.0.0.\n",
+            "We recommend preparing your data for import using castForImport .")
   
    ##################################################################
   # Argument Validation
@@ -193,7 +195,7 @@ importRecords.redcapApiConnection <- function(rcon,
   checkmate::assert_list(x = api_param, 
                          names = "named", 
                          add = coll)
-  
+
   checkmate::reportAssertions(coll)
   
   
@@ -208,17 +210,25 @@ importRecords.redcapApiConnection <- function(rcon,
     which(names(data) %in% 
             c("redcap_survey_identifier",
               paste0(unique(MetaData$form_name), "_timestamp")))
-  if (length(w.remove)) data <- data[-w.remove]
+  if (length(w.remove) > 0) data <- data[-w.remove]
+  
+  mchoices <- which(vapply(data, inherits, logical(1), 'mChoice'))
+  if(length(mchoices) > 0)
+  {
+    coll$push(paste0(
+      "The variable(s) ", 
+      paste0(names(data)[mchoices], collapse=", "), 
+      " are mChoice formatted and cannot be imported."))
+  }
   
   # Validate field names
   unrecognized_names <- !(names(data) %in% c(with_complete_fields, REDCAP_SYSTEM_FIELDS))
-
   if (any(unrecognized_names))
   {
-    message("The variable(s) ", 
-            paste0(names(data)[unrecognized_names], collapse=", "), 
-            " are not found in the project and/or cannot be imported. They have been removed from the imported data frame.")
-    data <- data[!unrecognized_names]
+    coll$push(paste0(
+      "The variable(s) ", 
+      paste0(names(data)[unrecognized_names], collapse=", "), 
+      " are not found in the project and/or cannot be imported."))
   }
   
   # Check that the study id exists in data
