@@ -5,7 +5,6 @@
 #' @description Returns a data frame of subject events with missing values. 
 #' 
 #' @inheritParams common-rcon-arg
-#' @inheritParams common-dot-args
 #' @inheritParams common-api-args
 #' @param records `character(1)` A filename pointing to the raw records
 #'   download from REDCap.
@@ -17,15 +16,7 @@
 #'   desirable is if a patient did not experience an adverse event; 
 #'   the adverse event form would contain no data and the empty fields
 #'   should not be considered missing data.
-#' @param fixed_fields `character` A vector of field names that will be used as 
-#'   the identifying fields in the output summary. This always includes the record
-#'   identifier (ie, the first field in the data dictionary). By default it 
-#'   also includes any fields identified in `REDCAP_SYSTEM_FIELDS`, which
-#'   are fields that REDCap adds to exports to identify arms, events, etc..
-#' @param exportRecordsArgs named `list`. Arguments to pass to `exportRecords`. 
-#'   This allows for testing specific forms, events, and/or records. Internally, any 
-#'   setting passed for `factors, labels, dates, survey`, or `dag` 
-#'   arguments will be ignored.
+#' @param ... additional arguments passed to inner call of exportRecordsTyped.
 #'   
 #' @details The intention of this function is to generate a list of subject
 #'   events that are missing and could potentially be values that should have
@@ -68,8 +59,8 @@
 
 missingSummary <- function(rcon, 
                            excludeMissingForms = TRUE, 
-                           ..., 
-                           fixed_fields        = REDCAP_SYSTEM_FIELDS){
+                           ...)
+{
   UseMethod("missingSummary")
 }
 
@@ -78,12 +69,8 @@ missingSummary <- function(rcon,
 
 missingSummary.redcapApiConnection <- function(rcon, 
                                                excludeMissingForms = TRUE, 
-                                               ...,
-                                               fixed_fields        = REDCAP_SYSTEM_FIELDS,
-                                               exportRecordsArgs   = list(),
-                                               error_handling      = getOption("redcap_error_handling"), 
-                                               config              = list(), 
-                                               api_param           = list()){
+                                               ...)
+{
   coll <- checkmate::makeAssertCollection()
   
   checkmate::assert_class(x = rcon,
@@ -94,47 +81,9 @@ missingSummary.redcapApiConnection <- function(rcon,
                             len = 1, 
                             add = coll)
   
-  checkmate::assert_character(x = fixed_fields, 
-                              add = coll)
-  
-  checkmate::assert_list(x = exportRecordsArgs, 
-                         names = "named", 
-                         add = coll)
-  
-  error_handling <- checkmate::matchArg(x = error_handling,
-                                        choices = c("null", "error"),
-                                        .var.name = "error_handling",
-                                        add = coll)
-  
-  checkmate::assert_list(x = config, 
-                         names = "named", 
-                         add = coll)
-  
-  checkmate::assert_list(x = api_param, 
-                         names = "named", 
-                         add = coll)
-  
   checkmate::reportAssertions(coll)
   
-  # Import the records ----------------------------------------------
-  # records will be used to store the results of tests for missingness
-  # records_orig will be used to conduct the tests
-  exportRecordsArgs <- exportRecordsArgs[!names(exportRecordsArgs) %in% c("factors", 
-                                                                          "labels", 
-                                                                          "dates", 
-                                                                          "survey", 
-                                                                          "dag", 
-                                                                          "rcon")]
-  exportRecordsArgs <- c(exportRecordsArgs, 
-                         list(rcon = rcon, 
-                              factors = FALSE, 
-                              labels = TRUE, 
-                              dates = FALSE, 
-                              survey = FALSE, 
-                              dag = TRUE))
-  
-  RecordsOrig <- do.call("exportRecords", 
-                         exportRecordsArgs)
+  RecordsOrig <- exportRecordsTyped(rcon, cast=raw_cast,...)
   
   # Import the Meta Data --------------------------------------------
   MetaData <- rcon$metadata()
@@ -162,8 +111,7 @@ missingSummary.redcapApiConnection <- function(rcon,
 
 missingSummary_offline <- function(records, 
                                    meta_data, 
-                                   excludeMissingForms = TRUE, 
-                                   fixed_fields = REDCAP_SYSTEM_FIELDS){
+                                   excludeMissingForms = TRUE){
   coll <- checkmate::makeAssertCollection()
   
   checkmate::assert_file_exists(x = records, 
@@ -230,9 +178,7 @@ missingSummary_offline <- function(records,
     if (!this_field %in% c(REDCAP_SYSTEM_FIELDS, 
                            meta_data$field_name[1]) & 
         !is.null(this_logic)){
-      
-      
-      
+   
       # get the name of the form on which the field is saved
       tmp_form <- meta_data$form_name[meta_data$field_name == 
                                         sub("___[[:print:]]", "", names(records)[i])]
@@ -258,6 +204,7 @@ missingSummary_offline <- function(records,
                                no = is.na(records_orig[[i]]))
       }
       else
+      {
         # Here we have branching logic.
         # If the `[form]_complete` field is missing, we return FALSE
         # If the `[form]_complete` is non-missing:
@@ -267,7 +214,8 @@ missingSummary_offline <- function(records,
                                yes = FALSE,
                                no = ifelse(test = with(records_orig, eval(this_logic)), 
                                            yes = is.na(records_orig[[i]]),
-                                           no = FALSE))  
+                                           no = FALSE))
+      }
     }
   }
   records
