@@ -100,86 +100,6 @@
 #####################################################################
 # Preserve Project                                               ####
 
-#' @rdname purgeRestoreProject
-#' @export
-
-preserveProject <- function(object, 
-                            ...){
-  UseMethod("preserveProject")
-}
-
-#' @rdname purgeRestoreProject
-#' @export
-
-preserveProject.redcapApiConnection <- function(object,
-                                                ..., 
-                                                error_handling = getOption("redcap_error_handling"), 
-                                                config         = list()){
-  ###################################################################
-  # Argument Validation                                          ####
-  
-  coll <- checkmate::makeAssertCollection()
-  
-  checkmate::assert_class(x = object, 
-                          classes = "redcapApiConnection", 
-                          add = coll)
-  
-  error_handling <- checkmate::matchArg(x = error_handling, 
-                                        choices = c("null", "error"), 
-                                        .var.name = "error_handling",
-                                        add = coll)
-  
-  checkmate::assert_list(x = config, 
-                         names = "named", 
-                         add = coll)
-  
-  checkmate::reportAssertions(coll)
-  
-  ###################################################################
-  # Make the List object                                         ####
-  
-  RedcapList <- 
-    list(project_information   = exportProjectInformation(object, 
-                                                          error_handling = error_handling, 
-                                                          config = config),
-         arms                  = exportArms(object, 
-                                            error_handling = error_handling, 
-                                            config = config), 
-         events                = exportEvents(object, 
-                                              error_handling = error_handling, 
-                                              config = config), 
-         meta_data             = exportMetaData(object, 
-                                                error_handling = error_handling, 
-                                                config = config),
-         mappings              = exportMappings(object, 
-                                                error_handling = error_handling, 
-                                                config = config), 
-         repeating_instruments = exportRepeatingInstrumentsEvents(object, 
-                                                                  error_handling = error_handling, 
-                                                                  config = config),
-         users                 = exportUsers(object, 
-                                             error_handling = error_handling, 
-                                             config = config), 
-         user_roles            = exportUserRoles(object,
-                                                 error_handling = error_handling, 
-                                                 config = config), 
-         user_role_assignments = exportUserRoleAssignments(object, 
-                                                           error_handling = error_handling, 
-                                                           config = config),
-         dags                  = exportDags(object, 
-                                            error_handling = error_handling, 
-                                            config = config),
-         dag_assignments       = exportUserDagAssignments(object, 
-                                                          error_handling = error_handling, 
-                                                          config = config),
-         records               = exportRecordsTyped(object, 
-                                                    cast = raw_cast,
-                                                    error_handling = error_handling, 
-                                                    config = config)
-    )
-  
-  RedcapList
-}
 
 #####################################################################
 # Purge Project                                                  ####
@@ -280,7 +200,7 @@ purgeProject.redcapApiConnection <- function(object,
                                    error_handling = error_handling, 
                                    config = config)
     
-    if (nrow(RecordId)){
+    if (nrow(RecordId)>0){
       if ("redcap_event_name" %in% names(RecordId)){
         RecordId$arm_num <- sub("^(.+)(arm_)(\\d+)$", "\\3", RecordId$redcap_event_name)
         
