@@ -2,6 +2,7 @@ context("makeApiCall Argument Validation")
 
 library(mockery)
 library(curl)
+library(httr)
 
 # Note: This file will only test that arguments fail appropriately, or
 # that submethods perform as expected. the makeApiCall function 
@@ -46,8 +47,9 @@ test_that(
   {
     h <- new_handle(timeout = 1L)
     e <- structure(
-      list(message = "Timeout was reached: [redcap.vanderbilt.edu] Operation timed out after 300001 milliseconds with 0 bytes received", 
-           call = curl_fetch_memory("https://redcap.vanderbilt.edu/api/params", handle = h)
+      list(message = paste0("Timeout was reached: [", url,
+                            "] Operation timed out after 300001 milliseconds with 0 bytes received"), 
+           call = curl_fetch_memory(paste0(url,"/params"), handle = h)
       ),
       class = c("simpleError", "error", "condition")
     )
@@ -71,7 +73,7 @@ test_that(
   {
     h <- new_handle(timeout = 1L)
     goodVersionPOST <- structure(
-      list(url = "https://redcap.vanderbilt.edu/api/",
+      list(url = url,
            status_code = 200L,
            content = charToRaw("13.10.3"),
            headers=structure(list(
@@ -80,8 +82,9 @@ test_that(
            class = c("insensitive", "list")),
       class = "response")
     e <- structure(
-           list(message = "Timeout was reached: [redcap.vanderbilt.edu] Operation timed out after 300001 milliseconds with 0 bytes received", 
-                call = curl_fetch_memory("https://redcap.vanderbilt.edu/api/params", handle = h)
+           list(message = paste0("Timeout was reached: [", url,
+                            "] Operation timed out after 300001 milliseconds with 0 bytes received"),
+                call = curl_fetch_memory(paste0(url,"/params"), handle = h)
                 ),
            class = c("simpleError", "error", "condition")
     )
@@ -127,7 +130,7 @@ test_that(
     expect_error(redcapError(response, "null"), 
                  "A network error has occurred. This can happen when too much data is")
     
-    response$content <- charToRaw("Timeout was reached: [redcap.vanderbilt.edu] SSL connection timeout")
+    response$content <- charToRaw(paste0("Timeout was reached: [",url,"] SSL connection timeout"))
     
     expect_error(redcapError(response, "null"), 
                  "A network error has occurred. This can happen when too much data is")
@@ -196,4 +199,69 @@ test_that(
     )
     
   }
+)
+
+test_that(
+  "makeApiCall handles permanent redirect",
+  {
+    local_reproducible_output(width = 200)
+    h <- new_handle(timeout = 1L)
+    redirect <- structure(
+      list(url = "https://test.xyz/api",
+           status_code = 301L,
+           content = "",
+           headers=structure(list(
+             'content-type'="text/csv; charset=utf-8",
+             'location'=url
+           ),
+           class = c("insensitive", "list")),
+      class = "response")
+    )
+    
+    redirectCall <- TRUE
+    stub(makeApiCall, "httr::POST", function(...)
+      if(redirectCall) { redirectCall <<- FALSE; redirect  } else {httr:::POST(...)})
+    
+    expect_warning(
+      response <- makeApiCall(rcon, 
+                        body = list(content = "version", 
+                                    format = "csv")),
+      paste0("Permanent 301 redirect https://test.xyz/api to ", url)
+    )
+    
+    expect_equal(response$status_code, 200L)
+  }
+)
+
+test_that(
+  "makeApiCall handles temporary redirect",
+  {
+    local_reproducible_output(width = 200)
+
+    h <- new_handle(timeout = 1L)
+    redirect <- structure(
+      list(url = "https://test.xyz/api",
+           status_code = 302L,
+           content = "",
+           headers=structure(list(
+             'content-type'="text/csv; charset=utf-8",
+             'location'=url
+           ),
+           class = c("insensitive", "list")),
+      class = "response")
+    )
+    
+    redirectCall <- TRUE
+    stub(makeApiCall, "httr::POST", function(...)
+      if(redirectCall) { redirectCall <<- FALSE; redirect  } else {httr:::POST(...)})
+    
+    expect_message(
+      response <- makeApiCall(rcon, 
+                        body = list(content = "version", 
+                                    format = "csv")),
+      paste0("Temporary 302 redirect https://test.xyz/api to ", url)
+    )
+    
+    expect_equal(response$status_code, 200L)
+  }
 )
\ No newline at end of file
